==> linuxconf-tools-1.1.src.tar.gz: linuxconf-tools-1.1/projetx/fuslog.cc <==
#include <stdarg.h>
#include <stdlib.h>
#include <dialog.h>
#include "projet.h"
#include "projetx.m"

/* #Spcification: fusion / dition / log oprateur
	Un fichier fusion.log est cr durant l'intgration dans la racine
	des projets. Ce fichier contient un log des transactions raliser
	durant l'dition d'une fusion.

	A chaque fois qu'on opre sur un fichier (slection d'une rvision
	effacage, etc...), une ligne est enregistre.

	Ce fichier n'est pas cumulatif. Il ne montre que ce qui a t
	fait durant une rvision. Pour l'instant, le fichier va dans
	la racine. Il est donc archiv. Voici les usages prvue:
#
	-Bilan rapide de ce qui a t intgr. Autant pour l'intgrateur
	 que pour ceux qui se demande si leur contribution ont bien
	 t intgre.
	-L'oprateur pourra y ajouter des notes dans le style, je n'ai
	 pas intgrer ca parce que...
#
*/
#
static char *titre = NULL;
/*
	Ajoute une ligne (ou plusieurs) dans le fichier fusion.log de la racine
*/
void fuslog_add (
	const USERINFO *user,
	const char *ctl,
	...)
{
	char path[MAXSIZ_PATH];
	path_make (user->getusrpath(),"fusion.log",path);
	FILE *fout = fopen_err (path,"a",0);
	if (fout != NULL){
		if (titre != NULL){
			fprintf (fout,"%s\n=====================\n",titre);
			free (titre);
			titre = NULL;
		}
		va_list list;
		va_start (list,ctl);
		vfprintf (fout,ctl,list);
		va_end (list);
		fclose (fout);
	}
}
/*
	Enregistre un titre qui sera plac dans le log ds qu'un message
	est gnr. Le titre ne sera plac qu'une seule fois.
*/
void fuslog_settitre (const char *str)
{
	free (titre);
	titre = strdup_err (str);
}

/*
	Edition (via un diteur de texte) du fichier fusion.log
*/
void fuslog_edit (
	long mskwin,
	EVENT *cmd,
	BOUTON_FCT *but,	// Sert  positionner le dialogue
						// Peut tre NULL.
	const USERINFO *user)
{
	/* #Spcification: fusion / dition / log oprateur
		En tout temps, lors de l'dition de l'intgration, l'oprateur
		peut commander l'dition du fichier fusion.log de la racine.

		Cela dclenche simplement un diteur de texte sur ce fichier.

		Le fichier fusion.log n'a pas de format prcis, donc l'oprateur
		peut y crire tout ce qui lui passe par la tte.
	*/
	PAGE_EDIT page ("fusion.log");
	int reste = vdiinfo.y_max - 4*pen_info.std_height;
	int nblin = reste/pen_info.std_height-1;
	if (nblin > 25) nblin = 25;
	int nbcol = vdiinfo.x_max / pen_info.std_width - 4;
	if (nbcol > 80) nbcol = 80;
	page_setupptexte (&page,nblin,nbcol,1);
	bouton_setupstd (&page,"save cancel");
	char path[MAXSIZ_PATH];
	path_make (user->getusrpath(),"fusion.log",path);
	FILE_TEXTE file (path);
	page_loadptexte (&page,0,&file);
	page_setuptitre0 (&page,"%s",path);
	page.coldesign();
	if (but != NULL) page.setspec (but);
	if (page.edit (mskwin,cmd)==PAGE_VAL_SAVE){
		file.save();
	}
}

static PAGE_VAL fuslog_edit (
	long mskwin,
	EVENT *cmd,
	BOUTON_FCT *but,
	void *data)
{
	USERINFO *user = (USERINFO*)data;
	fuslog_edit(mskwin,cmd,but,user);
	return PAGE_VAL_NULL;
}
/*
	Enregistre un bouton controllant l'dition du fichier fusion.log
	de la racine.

	Le bouton ajout est de type bouton_setupfct().

	Retourne -1 si erreur.
*/
int fuslog_setbutton (
	PAGE_EDIT *page,
	const USERINFO *user)		// Cet objet sera mmoris et doit
						// exister tout au long du dialogue.
{
	return bouton_setupfct (page,MSGBUT_EDITLOG,K_NULL,fuslog_edit,(void*)user);
}

==> linuxconf-tools-1.7.src.tar.gz: linuxconf-tools-1.7/projetx/fuslog.cc <==
#include <stdarg.h>
#include <stdlib.h>
#include <dialog.h>
#include "projet.h"
#include "projetx.m"

/* #Spcification: fusion / dition / log oprateur
	Un fichier fusion.log est cr durant l'intgration dans la racine
	des projets. Ce fichier contient un log des transactions raliser
	durant l'dition d'une fusion.

	A chaque fois qu'on opre sur un fichier (slection d'une rvision
	effacage, etc...), une ligne est enregistre.

	Ce fichier n'est pas cumulatif. Il ne montre que ce qui a t
	fait durant une rvision. Pour l'instant, le fichier va dans
	la racine. Il est donc archiv. Voici les usages prvue:
#
	-Bilan rapide de ce qui a t intgr. Autant pour l'intgrateur
	 que pour ceux qui se demande si leur contribution ont bien
	 t intgre.
	-L'oprateur pourra y ajouter des notes dans le style, je n'ai
	 pas intgrer ca parce que...
#
*/
#
static char *titre = NULL;
/*
	Ajoute une ligne (ou plusieurs) dans le fichier fusion.log de la racine
*/
void fuslog_add (
	const USERINFO *user,
	const char *ctl,
	...)
{
	char path[MAXSIZ_PATH];
	path_make (user->getusrpath(),"fusion.log",path);
	FILE *fout = fopen_err (path,"a",0);
	if (fout != NULL){
		if (titre != NULL){
			fprintf (fout,"%s\n=====================\n",titre);
			free (titre);
			titre = NULL;
		}
		va_list list;
		va_start (list,ctl);
		vfprintf (fout,ctl,list);
		va_end (list);
		fclose (fout);
	}
}
/*
	Enregistre un titre qui sera plac dans le log ds qu'un message
	est gnr. Le titre ne sera plac qu'une seule fois.
*/
void fuslog_settitre (const char *str)
{
	free (titre);
	titre = strdup_err (str);
}

/*
	Edition (via un diteur de texte) du fichier fusion.log
*/
void fuslog_edit (const USERINFO *user)
{
	/* #Spcification: fusion / dition / log oprateur
		En tout temps, lors de l'dition de l'intgration, l'oprateur
		peut commander l'dition du fichier fusion.log de la racine.

		Cela dclenche simplement un diteur de texte sur ce fichier.

		Le fichier fusion.log n'a pas de format prcis, donc l'oprateur
		peut y crire tout ce qui lui passe par la tte.
	*/
	DIALOG dia;
	char path[MAXSIZ_PATH];
	path_make (user->getusrpath(),"fusion.log",path);
	#ifdef MISSING
		page_setupptexte (&page,nblin,nbcol,1);
		FILE_TEXTE file (path);
		page_loadptexte (&page,0,&file);
	#endif
	int nof = 0;
	if (dia.edit (path,"",help_nil,nof)==MENU_ACCEPT){
		#ifdef MISSING
			file.save();
		#endif
	}
}

/*
	Enregistre un bouton controllant l'dition du fichier fusion.log
	de la racine.

	Le bouton ajout est de type bouton_setupfct().

	Retourne -1 si erreur.
*/
void fuslog_setbutton (
	DIALOG &dia,
	const USERINFO *)		// Cet objet sera mmoris et doit
							// exister tout au long du dialogue.
{
	dia.setbutinfo (MENU_USR1,MSG_U(B_EDITLOG,"Editlog"),MSG_R(B_EDITLOG));
}
